[Author Prev][Author Next][Thread Prev][Thread Next][Author Index][Thread Index]
[tor-commits] [tor-messenger-build/master] Rebase patches
commit 392518c6da62a2aab39c33725983b7667f28262b
Author: Arlo Breault <arlolra@xxxxxxxxx>
Date: Sat Nov 7 19:43:38 2015 -0800
Rebase patches
---
projects/instantbird/trac-16476.patch | 31 +++++++++++++++----------------
projects/instantbird/trac-17552.patch | 18 +++++++++---------
2 files changed, 24 insertions(+), 25 deletions(-)
diff --git a/projects/instantbird/trac-16476.patch b/projects/instantbird/trac-16476.patch
index 96eabb4..720a470 100644
--- a/projects/instantbird/trac-16476.patch
+++ b/projects/instantbird/trac-16476.patch
@@ -1,38 +1,37 @@
# HG changeset patch
# User aleth <aleth@xxxxxxxxxxxxxxx>
-# Date 1446853955 -3600
-# Sat Nov 07 00:52:35 2015 +0100
-# Node ID 1f09dc616d2e058779753327637b85f6dcc0bbf1
-# Parent 073468887b0faecb810a6e4463a2806924fead81
+# Date 1446954539 28800
+# Sat Nov 07 19:48:59 2015 -0800
+# Branch GECKO410b1_2015090809_RELBRANCH
+# Node ID 47ab76be5ae63ddaef16a424243ed3acc403f94f
+# Parent 492c769c46c9ea9e54fab00d6f0310afd100885a
Bug 1222238 - Avoid hang in proxy preferences pane. r=clokep
diff --git a/projects/instantbird/trac-17552.patch b/projects/instantbird/trac-17552.patch
index f4ff411..442bbe9 100644
--- a/projects/instantbird/trac-17552.patch
+++ b/projects/instantbird/trac-17552.patch
@@ -1,15 +1,15 @@
# HG changeset patch
# User Arlo Breault <arlolra@xxxxxxxxx>
-# Date 1446859847 28800
-# Fri Nov 06 17:30:47 2015 -0800
-# Node ID b9b0e61d9a2d5092d45b309feb4ae526ae00519c
-# Parent 073468887b0faecb810a6e4463a2806924fead81
+# Date 1446953889 28800
+# Sat Nov 07 19:38:09 2015 -0800
+# Node ID a42c96a62dee7a73910de738a9809d8247aede8c
+# Parent 492c769c46c9ea9e54fab00d6f0310afd100885a
Ensure isMuc when attempting a subject change
diff --git a/chat/protocols/xmpp/xmpp.jsm b/chat/protocols/xmpp/xmpp.jsm
--- a/chat/protocols/xmpp/xmpp.jsm
+++ b/chat/protocols/xmpp/xmpp.jsm
-@@ -1718,16 +1718,17 @@ var XMPPAccountPrototype = {
+@@ -1343,16 +1343,17 @@ const XMPPAccountPrototype = {
return null;
},
@@ -21,13 +21,13 @@ diff --git a/chat/protocols/xmpp/xmpp.jsm b/chat/protocols/xmpp/xmpp.jsm
+ let isMuc = this._mucs.has(norm);
let type = aStanza.attributes["type"];
- let x = aStanza.getElement(["x"]);
let body;
let b = aStanza.getElement(["body"]);
if (b) {
// If there's a <body> child we have more than just typing notifications.
// Prefer HTML (in <html><body>) and use plain text (<body>) as fallback.
-@@ -1738,17 +1739,21 @@ var XMPPAccountPrototype = {
+ let htmlBody = aStanza.getElement(["html", "body"]);
+@@ -1362,17 +1363,21 @@ const XMPPAccountPrototype = {
// Even if the message is in plain text, the prplIMessage
// should contain a string that's correctly escaped for
// insertion in an HTML document.
@@ -50,7 +50,7 @@ diff --git a/chat/protocols/xmpp/xmpp.jsm b/chat/protocols/xmpp/xmpp.jsm
// before 15.06.
let muc = this._mucs.get(norm);
let nick = this._parseJID(from).resource;
-@@ -1763,18 +1768,18 @@ var XMPPAccountPrototype = {
+@@ -1386,18 +1391,18 @@ const XMPPAccountPrototype = {
let delay = aStanza.getElement(["delay"]);
if (delay && delay.uri == Stanza.NS.delay) {
if (delay.attributes["stamp"])
@@ -71,7 +71,7 @@ diff --git a/chat/protocols/xmpp/xmpp.jsm b/chat/protocols/xmpp/xmpp.jsm
return;
}
-@@ -1840,17 +1845,17 @@ var XMPPAccountPrototype = {
+@@ -1454,17 +1459,17 @@ const XMPPAccountPrototype = {
if (state) {
this.DEBUG(state);
if (state == "composing")
_______________________________________________
tor-commits mailing list
tor-commits@xxxxxxxxxxxxxxxxxxxx
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits
diff --git a/im/content/preferences/messagestyle.js b/im/content/preferences/messagestyle.js
--- a/im/content/preferences/messagestyle.js
+++ b/im/content/preferences/messagestyle.js
-@@ -169,22 +169,20 @@ var previewObserver = {
+@@ -166,16 +166,24 @@ var previewObserver = {
+ this.browser._theme = this.theme;
+ Services.obs.addObserver(this, "conversation-loaded", false);
+ },
observe: function(aSubject, aTopic, aData) {
if (aTopic != "conversation-loaded" || aSubject != this.browser)
return;
- // We want to avoid the convbrowser trying to scroll to the last
- // added message, as that causes the entire pref pane to jump up
- // (bug 1179943). Therefore, we override the method convbrowser
-- // uses to determine if there are further messages pending to be
-- // added. The +1 ensures no scroll occurs after we add the last
-- // message here.
-- this.browser._autoScrollEnabled = false;
-- this.browser.getPendingMessagesCount =
-- () => previewObserver.conv.messages.length + 1;
++ // We want to avoid the convbrowser trying to scroll to the last
++ // added message, as that causes the entire pref pane to jump up
++ // (bug 1179943). Therefore, we override the method convbrowser
+ // uses to determine if it should scroll, as well as its
+ // mirror in the contentWindow (that messagestyle JS can call).
+ this.browser.autoScrollEnabled = () => false;
+ this.browser.contentWindow.autoScrollEnabled = () => false;
-
++
// Display all queued messages. Use a timeout so that message text
// modifiers can be added with observers for this notification.
setTimeout(function() {
- for (let message of previewObserver.conv.messages)
+ for each (let message in previewObserver.conv.messages)
aSubject.appendMessage(message, false);
}, 0);
+ Services.obs.removeObserver(this, "conversation-loaded");